<?php
/*
*
* @package LMDI Multilinks
* @copyright (c) 2017 Pierre Duhem - LMDI
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

namespace lmdi\multilinks\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{

	protected $db;
	protected $user;
	protected $config;
	protected $config_text;
	protected $template;
	protected $table;


	public function __construct(
		\phpbb\db\driver\driver_interface $db,
		\phpbb\config\config $config,
		\phpbb\template\template $template,
		$ml_table)
	{
		$this->db = $db;
		$this->config = $config;
		$this->template = $template;
		$this->table = $ml_table;
	}


	static public function getSubscribedEvents ()
	{
		return array(
			'core.user_setup'	=> 'load_language',
			'core.page_header'	=> 'build_navbar_links',
			// ACP event
			'core.permissions'	=> 'add_permission',
		);
	}


	/**
	* Load the language strings
	*/
	public function load_language ($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'lmdi/multilinks',
			'lang_set' => 'multilinks',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}


	/**
	* Add administrative permissions to manage multilinks
	*/
	public function add_permission($event)
	{
		$permissions = $event['permissions'];
		$permissions['a_multilinks'] = array('lang' => 'ACL_A_MULTILINKS', 'cat' => 'misc');
		$event['permissions'] = $permissions;
	}


	/**
	* Construction of the links to inject in the navbar
	*/
	public function build_navbar_links ($event)
	{
		if (version_compare ($this->config['version'], '3.2.x', '<'))
		{
			$mlinks_320 = 0;
		}
		else
		{
			$mlinks_320 = 1;
		}

		$this->local_assign_block_vars(0 /* Prepend */, 'mlpp');
		$this->local_assign_block_vars(1 /* Append */, 'mlap');

		$this->template->assign_vars(array(
			'S_320'	=> $mlinks_320,
			));
	}


	private function local_assign_block_vars($ppap, $block)
	{
		$sql = "SELECT * FROM " . $this->table . " WHERE ppap = $ppap AND enabled = 1";
		$result = $this->db->sql_query($sql);
		while ($row = $this->db->sql_fetchrow($result))
		{
			$icon = $row['icon'];
			$usicon = $row['usicon'];
			$pict = $row['pict'];
			$this->template->assign_block_vars($block, array(
				'NAME'	=> $row['anchor'],
				'TITLE'	=> $row['title'],
				'URL'	=> $row['url'],
				'BLANK'	=> $row['blank']==true ? 'target="_blank"' : '',
				'ICON'	=> $icon,
				'FILE'	=> $pict,
				'S_ICON'	=> $usicon,
				));
		}
		$this->db->sql_freeresult($result);
	}
}
